//--------------------------------------------------------------
// File     : main.c
// Datum    : 29.10.2013
// Version  : 1.1
// Autor    : UB
// EMail    : mc-4u(@)t-online.de
// Web      : www.mikrocontroller-4u.de
// CPU      : STM32F429
// IDE      : CooCox CoIDE 1.7.4
// GCC      : 4.7 2012q4
// Module   : CMSIS_BOOT, M4_CMSIS_CORE
// Funktion : Demo der LCD-Library (ILI9341)
// Hinweis  : Diese zwei Files muessen auf 8MHz stehen
//              "cmsis_boot/stm32f4xx.h"
//              "cmsis_boot/system_stm32f4xx.c"
// In Configuration diese Define hinzufgen :
// "STM32F429_439xx" , "__ASSEMBLY__" , "USE_STDPERIPH_DRIVER"
//--------------------------------------------------------------

#include "main.h"
#include "stm32f4xx_conf.h"
#include "stm32_ub_lcd_ili9341.h"
#include "stm32_ub_graphic2d.h"
#include "stm32_ub_font.h"
#include "stm32f4xx_tim.h"
#include "stm32f4xx_rcc.h"
#include "stm32f4xx.h"
#include "misc.h"
#include "stm32f4xx_gpio.h"
#include "stm32f4xx_can.h"



volatile unsigned char X_pos[15];


int main(void)
{
  uint32_t n;




  SystemInit(); // Quarz Einstellungen aktivieren





  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOG,ENABLE);

    // Strukturen festlegen
    GPIO_InitTypeDef GPIO_InitGPIO;

    // Pin Parameter einstellen
    GPIO_InitGPIO.GPIO_Pin = (GPIO_Pin_14);
    GPIO_InitGPIO.GPIO_Mode = GPIO_Mode_OUT;
    GPIO_InitGPIO.GPIO_OType = GPIO_OType_PP;
    GPIO_InitGPIO.GPIO_PuPd = GPIO_PuPd_NOPULL;
    GPIO_InitGPIO.GPIO_Speed = GPIO_Speed_50MHz;

    // Port initialisieren
    GPIO_Init(GPIOG, &GPIO_InitGPIO);



  TIM_TimeBaseInitTypeDef TIM_TimeBaseInitTIM;
  NVIC_InitTypeDef NVIC_InitStructure;

  // Takt fr Timer2 einschalten
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM2, ENABLE);

  // Timer 2 konfigurieren
  TIM_TimeBaseInitTIM.TIM_ClockDivision = TIM_CKD_DIV1;
  TIM_TimeBaseInitTIM.TIM_CounterMode = TIM_CounterMode_Up;
  TIM_TimeBaseInitTIM.TIM_Period = 700;
  TIM_TimeBaseInitTIM.TIM_Prescaler = 17999;
  TIM_TimeBaseInit(TIM2, &TIM_TimeBaseInitTIM);

  TIM_ITConfig(TIM2, TIM_IT_Update, ENABLE);

  // Timer Interrupt konfigurieren
  NVIC_InitStructure.NVIC_IRQChannel = TIM2_IRQn;
  NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
  NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0x0F;
  NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0x0F;
  NVIC_Init(&NVIC_InitStructure);

  // Timer starten
  TIM_Cmd(TIM2, ENABLE);




  // Init vom LCD
  UB_LCD_Init();
  // Init der Layer
  UB_LCD_LayerInit_Fullscreen();
  // auf Hintergrund schalten
  UB_LCD_SetLayer_1();
  // Hintergrund komplett mit einer Farbe fllen
  UB_LCD_FillLayer(RGB_COL_WHITE);
  // auf Vordergrund schalten
  UB_LCD_SetLayer_2();
  // Vordergrund komplett mit einer Farbe fllen
  UB_LCD_FillLayer(RGB_COL_BLACK);

//Testrechteck zeichnen
  UB_Graphic2D_DrawFullRectDMA(150, 30, 50, 50, 990);





//__________CAN INIT__________
  CAN_InitTypeDef CAN_InitStructure;
  GPIO_InitTypeDef GPIO_InitStructure;
  CAN_FilterInitTypeDef CAN_FilterInitStructure;

  RCC_APB1PeriphClockCmd(RCC_APB1Periph_CAN1, ENABLE);
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_CAN2, ENABLE);

  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOB, ENABLE);
  GPIO_PinAFConfig(GPIOB, GPIO_PinSource12, GPIO_AF_CAN2);
  GPIO_PinAFConfig(GPIOB, GPIO_PinSource13, GPIO_AF_CAN2);

  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_12 | GPIO_Pin_13;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_UP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOB, &GPIO_InitStructure);

  CAN_DeInit(CAN2);
  CAN_InitStructure.CAN_ABOM = DISABLE;
  CAN_InitStructure.CAN_AWUM = DISABLE;
  CAN_InitStructure.CAN_Mode = CAN_Mode_Normal;
  CAN_InitStructure.CAN_NART = DISABLE;
  CAN_InitStructure.CAN_RFLM = DISABLE;
  CAN_InitStructure.CAN_SJW  = CAN_SJW_1tq;
  CAN_InitStructure.CAN_TTCM = DISABLE;
  CAN_InitStructure.CAN_TXFP = DISABLE;

  CAN_InitStructure.CAN_BS1 = CAN_BS1_12tq;
  CAN_InitStructure.CAN_BS2 = CAN_BS2_5tq;
  CAN_InitStructure.CAN_Prescaler = 5;
  CAN_Init(CAN2, &CAN_InitStructure);

    // Init the CAN filter
    CAN_FilterInitStructure.CAN_FilterActivation = ENABLE;
    CAN_FilterInitStructure.CAN_FilterFIFOAssignment = 0;
    CAN_FilterInitStructure.CAN_FilterIdHigh = 0x0000;
    CAN_FilterInitStructure.CAN_FilterIdLow = 0x0000;
    CAN_FilterInitStructure.CAN_FilterMaskIdHigh = 0x0000;
    CAN_FilterInitStructure.CAN_FilterMaskIdLow = 0x0000;
    CAN_FilterInitStructure.CAN_FilterMode = CAN_FilterMode_IdMask;
    CAN_FilterInitStructure.CAN_FilterNumber = 0;
    CAN_FilterInitStructure.CAN_FilterScale = CAN_FilterScale_32bit;
    CAN_FilterInit(&CAN_FilterInitStructure);

//    NVIC_InitTypeDef NVIC_InitStructure;
    NVIC_InitStructure.NVIC_IRQChannel = CAN2_RX0_IRQn;
    NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
    NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0x01;
    NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0x01;
    NVIC_Init(&NVIC_InitStructure);

    // Enable "FIFO 0 message pending" interrupt
    CAN_ITConfig(CAN2, CAN_IT_FMP0, ENABLE);

//__________ENDE CAN INIT



  while(1)
  {

	  }
}




void TIM2_IRQHandler(void){
 TIM_ClearITPendingBit(TIM2, TIM_IT_Update);

  if(GPIO_ReadOutputDataBit(GPIOG, GPIO_Pin_14)){
      GPIO_WriteBit(GPIOG, GPIO_Pin_14, RESET);
    }else{
      GPIO_WriteBit(GPIOG, GPIO_Pin_14, SET);
    }

}

void CAN2_RX0_IRQHandler()
{
  // Check CAN2_Rx status
//  if( CAN_GetITStatus(CAN2, CAN_IT_FMP0))
//  {
	  if(GPIO_ReadOutputDataBit(GPIOG, GPIO_Pin_13)){
	        GPIO_WriteBit(GPIOG, GPIO_Pin_13, RESET);
	      }else{
	        GPIO_WriteBit(GPIOG, GPIO_Pin_13, SET);
	      }

    // Clear CAN buffer
//  clear_CanRxMessage();
//  }
}




